@@ -1,4 +1,4 @@
-// Copyright (C) 2018   John Donoghue   <john.donoghue@ieee.org>
+// Copyright (C) 2018-2019 John Donoghue <john.donoghue@ieee.org>
 // Copyright (C) 2013   Stefan Mahr     <dac922@gmx.de>
 // Copyright (C) 2012   Andrius Sutas   <andrius.sutas@gmail.com>
 //
@@ -38,7 +38,7 @@ public:
   int write (const std::string &);
   int write (uint8_t *, unsigned int);
 
-  int read (uint8_t *, unsigned int, int);
+  int read (uint8_t *, unsigned int, double);
 
   int open (const std::string &, int);
   int close (void);
@@ -46,8 +46,8 @@ public:
 
   int flush (int mode);
 
-  int set_timeout (int);
-  int get_timeout (void) const { return timeout; }
+  int set_timeout (double);
+  double get_timeout (void) const { return timeout; }
 
   // Overloaded base functions
   double tcp_value (void) const { return (double)fd; }
@@ -65,6 +65,26 @@ public:
   bool is_constant (void) const { return true;}
   bool is_defined (void) const { return true;}
   bool is_object (void) const { return true; }
+  // 4.4+
+  bool isobject (void) const { return true; }
+
+  // required to use subsasn
+  string_vector map_keys (void) const { return fieldnames; }
+  dim_vector dims (void) const { static dim_vector dv(1, 1); return dv; }
+
+  octave_base_value * unique_clone (void) { count++; return this; }
+ /**
+  * overloaded methods to get properties
+  */
+  octave_value_list subsref (const std::string& type, const std::list<octave_value_list>& idx, int nargout);
+
+  octave_value subsref (const std::string& type, const std::list<octave_value_list>& idx)
+  {
+    octave_value_list retval = subsref (type, idx, 1);
+    return (retval.length () > 0 ? retval(0) : octave_value ());
+  }
+
+  octave_value subsasgn (const std::string& type, const std::list<octave_value_list>& idx, const octave_value& rhs);
 
   int get_bytesavailable (void) const;
 
@@ -83,8 +103,10 @@ public:
 
   int get_local_port (void) const;
 private:
+  string_vector fieldnames;
+
   int fd;
-  int timeout;
+  double timeout;
 
   std::string name;
   sockaddr_in remote_addr;
