@@ -130,8 +130,8 @@ octave_udpport::octave_udpport (void)
   enableportsharing = 0;
   enablemulticastloopback = 0;
   enablebroadcast = 0;
-  interminator = "lf";
-  outterminator = "lf";
+  interminator = octave_value("lf");
+  outterminator = octave_value("lf");
 
   fieldnames[0] = "Type";
   fieldnames[1] = "Name";
@@ -750,7 +750,7 @@ octave_udpport::set_multicastgroup (const std::string &addr)
         {
           sockaddr_in in;
 
-          for (int i=0; i<multicastaddr.size (); i++)
+          for (int i=0; i<(int)multicastaddr.size (); i++)
             {
               struct ip_mreq multicastRequest;  /* Multicast address join structure */
 
@@ -819,27 +819,61 @@ octave_udpport::set_byteorder(const std::string& neworder)
 }
 
 int
-octave_udpport::set_input_terminator(const std::string& t)
+octave_udpport::set_input_terminator(const octave_value& t)
 {
-  std::string term = t;
-  std::transform (term.begin (), term.end (), term.begin (), ::tolower);
-  if (term != "lf" && term != "cr" && term != "cr/lf")
-    error ("octave_udpport invalid input terminator");
+  if(t.is_string())
+  {
+    std::string term = t.string_value();
+    std::transform (term.begin (), term.end (), term.begin (), ::tolower);
+    if (term != "lf" && term != "cr" && term != "cr/lf")
+      error ("octave_udpport invalid input terminator");
+    else
+      interminator = term;
+    }
+  else if(t.is_scalar_type())
+    {
+      int x = t.int_value();
+      if(x < 0 || x > 255)
+        {
+          error ("octave_udpport invalid input terminator");
+        }
+      else
+        {
+          interminator = octave_value(x);
+        }
+    }
   else
-    interminator = term;
+    error ("octave_udpport invalid input terminator");
 
- return 1;
+  return 1;
 }
 
 int
-octave_udpport::set_output_terminator(const std::string& t)
+octave_udpport::set_output_terminator(const octave_value& t)
 {
-  std::string term = t;
-  std::transform (term.begin (), term.end (), term.begin (), ::tolower);
-  if (term != "lf" && term != "cr" && term != "cr/lf")
-    error ("octave_udpport invalid output terminator");
+  if(t.is_string())
+  {
+    std::string term = t.string_value();
+    std::transform (term.begin (), term.end (), term.begin (), ::tolower);
+    if (term != "lf" && term != "cr" && term != "cr/lf")
+      error ("octave_udpport invalid output terminator");
+    else
+      outterminator = term;
+    }
+  else if(t.is_scalar_type())
+    {
+      int x = t.int_value();
+      if(x < 0 || x > 255)
+        {
+          error ("octave_udpport invalid output terminator");
+        }
+      else
+        {
+          outterminator = octave_value(x);
+        }
+    }
   else
-    outterminator = term;
+    error ("octave_udpport invalid output terminator");
 
  return 1;
 }
